@@ -1,5 +1,5 @@
 /* these get set by the ./configure script eventually */
 
 #undef PREFIX_INSTALL_PATH
-#undef HAVE_GGIMISC_H
+#undef HAVE_GGI_MISC_H
 
