@@ -41,4 +41,7 @@ void freeImage( struct image* i );
 void drawImage( struct image* i, uint32 destx, uint32 desty, uint32 destwidth, uint32 destheight, uint32 srcx, uint32 srcy );
 void image_clear_part( struct image* i, uint32 destx, uint32 desty, uint32 w, uint32 h );
 
+int image_create ( struct image* i, uint32 width, uint32 height );
+void image_blend ( struct image* src_image, struct image* dest_image );
+
 #endif /* __IMAGE_H */
