@@ -99,7 +99,7 @@ void blendBackground( struct image* i, uint32 srcx, uint32 srcy, float brightnes
 {
     uint32 x,y;
     uint32 destwidth,destheight;
-    uint32 row,col;
+    uint32 row;
     
     uint8 *from, *to;
 
@@ -117,12 +117,9 @@ void blendBackground( struct image* i, uint32 srcx, uint32 srcy, float brightnes
 
     for ( row = 0; row < destheight; row++ )
     {
-        for ( col = 0; col < destwidth; col++ )
-        {
-            *(to++) = ( *(from++) ) - 1;
-        }
-        to += i->dest->width - destwidth; 
-        from += i->width - destwidth;
+        memcpy ( to, from, destwidth );
+        to += i->dest->width; 
+        from += i->width;
     }
 }
 
@@ -303,7 +300,7 @@ void updatePage( struct state* s, struct graphics* g, struct screen* scrn, struc
 
             /* the blended part of the background image
                (center, beneath the text) */
-    blendBackground( &g->backgroundImage, xofs, yofs, fadePerunage );
+    blendBackground( &g->blended_background_image, xofs, yofs, fadePerunage );
 
             /* borders of the background image */
     updateBackground( &g->backgroundImage, s, xofs, yofs );
@@ -435,7 +432,11 @@ void doInterface( struct screen* scrn, struct graphics* g, struct music* m, stru
     while (s.globalState != GLOBALSTATE_QUIT ) {
 
         wait_next_frame ( &fc );
-        scroller_frame = update_frame_counter ( &fc_scroller );
+
+	if ( scrn->wait_retrace )
+	  scroller_frame += 1.0;
+	else
+	  scroller_frame = update_frame_counter ( &fc_scroller );
         
         switch ( s.globalState )
         {
